@@ -199,7 +199,7 @@ class Group(_Group):
         """
 
         group_data = api.delete_group(
-            self.__board,
+            self.__board.id,
             self.id, 
             *args,
             api_key=self.__creds.api_key_v2)
@@ -261,6 +261,8 @@ class Group(_Group):
 
                 column_values : `json`
                     The column values of the new item.
+                create_labels_if_missing: `bool`
+                    Create Status/Dropdown labels if they're missing. (Requires permission to change board structure).
         """
 
         item_data = api.create_item(
