@@ -818,7 +818,7 @@ class Item(_Item):
                 'as_model parameter must be of MondayModel Type')
         return [as_model(item) for item in items]
 
-    def change_column_value(self,id = None, title = None, column_value = None, get_column_values: bool = None, as_model: type = None, *args):
+    def change_column_value(self,id = None, title = None, column_value = None, get_column_values: bool = None, as_model: type = None, *args, **kwargs):
         """Get an item's column value by ID or title.
 
             Parameters
@@ -836,6 +836,8 @@ class Item(_Item):
                     The MondayModel subclass to be returned.
                 args : `tuple`
                     Optional item return fields.
+                kwargs : `dict`
+                    Optional arguments for creating subitems.
 
             Returns
 
@@ -870,6 +872,11 @@ class Item(_Item):
                     The item's last update date.
                 updates : `moncli.entities.update.Update`
                     The item's updates.
+            
+            Optional Arguments
+            
+                create_labels_if_missing: `bool`
+                    Create Status/Dropdown labels if they're missing. (Requires permission to change board structure).
         """
         if id and title : 
             raise e.ItemError(
@@ -923,7 +930,8 @@ class Item(_Item):
             self.board.id,
             value,
             *args,
-            api_key=self.__creds.api_key_v2)
+            api_key=self.__creds.api_key_v2,
+            **kwargs)
         items = Item(creds=self.__creds, **item_data)
         if not as_model:
             return items
@@ -934,7 +942,7 @@ class Item(_Item):
                 'as_model parameter must be of MondayModel Type')
         return [as_model(item) for item in items]
 
-    def change_simple_column_value(self, id = None, title = None, value = None,as_model: type = None, *args):
+    def change_simple_column_value(self, id = None, title = None, value = None, as_model: type = None, *args, **kwargs):
         """Change the item's column values using simple values.
 
             Parameters
@@ -949,6 +957,8 @@ class Item(_Item):
                     The value to be changed
                 args : `tuple`
                     Optional item return fields.
+                kwargs : `dict`
+                    Optional arguments for creating subitems.
 
             Returns
 
@@ -983,6 +993,11 @@ class Item(_Item):
                     The item's last update date.
                 updates : `moncli.entities.update.Update`
                     The item's updates.
+            
+            Optional Arguments
+            
+                create_labels_if_missing: `bool`
+                    Create Status/Dropdown labels if they're missing. (Requires permission to change board structure).
         """
         
         if not id and not title :
@@ -1001,7 +1016,8 @@ class Item(_Item):
             column_value.id,
             value,
             *args,
-            api_key=self.__creds.api_key_v2)        
+            api_key=self.__creds.api_key_v2,
+            **kwargs)        
 
         items = Item(creds=self.__creds, **item_data)
         if not as_model:
@@ -1013,7 +1029,7 @@ class Item(_Item):
                 'as_model parameter must be of MondayModel Type')
         return [as_model(item) for item in items]
 
-    def change_multiple_column_values(self, column_values, get_column_values: bool = False, as_model: type = None, *args):
+    def change_multiple_column_values(self, column_values, get_column_values: bool = False, as_model: type = None, *args, **kwargs):
         """Change the item's column values.
 
             Parameters
@@ -1027,6 +1043,8 @@ class Item(_Item):
                     The MondayModel subclass to be returned.
                 args : `tuple`
                     Optional item return fields.
+                kwargs : `dict`
+                    Optional arguments for creating subitems.
 
             Returns
 
@@ -1061,6 +1079,11 @@ class Item(_Item):
                     The item's last update date.
                 updates : `moncli.entities.update.Update`
                     The item's updates.
+            
+            Optional Arguments
+            
+                create_labels_if_missing: `bool`
+                    Create Status/Dropdown labels if they're missing. (Requires permission to change board structure).
         """
 
         if get_column_values:
@@ -1087,7 +1110,8 @@ class Item(_Item):
             self.board.id,
             values,
             *args,
-            api_key=self.__creds.api_key_v2)
+            api_key=self.__creds.api_key_v2,
+            **kwargs)
         items = Item(creds=self.__creds, **item_data)
         if not as_model:
             return items
@@ -1151,6 +1175,8 @@ class Item(_Item):
             
                 column_values : `json`
                     The column values of the new item.
+                create_labels_if_missing: `bool`
+                    Create Status/Dropdown labels if they're missing. (Requires permission to change board structure).
         """
         
         subitem_data = api.create_subitem(
